@@ -97,6 +97,8 @@ FinalType = TypeVar('FinalType')
 DelayedType = Callable[[ByteString], FinalType]
 MaybeDelayedType = Union[DelayedType[FinalType], FinalType]
 
+_DEFAULT_BITS = 64
+
 
 class ParserError(ArgumentTypeError): pass
 class ParserVariableMissing(ParserError): pass
@@ -356,6 +358,8 @@ class DelayedArgumentDispatch:
             hint = get_type_hints(handler).get(name, None)
             if hint == Iterable[type(data)]:
                 data = (data,)
+            if hint == str and isbuffer(data):
+                data = data.decode('utf8')
             return handler(instance, data, *args)
         except KeyError:
             unit = self._get_unit(modifier, *args)
@@ -497,7 +501,7 @@ class DelayedArgument(LazyEvaluation):
             return utf8(expression)
 
     @DelayedArgumentDispatch
-    def handler(self, expression: str) -> bytes:
+    def handler(self, expression) -> bytes:
         return self.default_handler(expression)
 
     @handler.register('s', 'S', final=True)
@@ -530,14 +534,24 @@ class DelayedArgument(LazyEvaluation):
         import base64
         return base64.b16decode(string, casefold=True)
 
-    @handler.register('f', 'F', 'file')
+    @handler.register('f', 'F', final=True)
+    def f(self, path: str, region: str = None) -> bytes:
+        """
+        Final variant of the `refinery.lib.argformats.DelayedArgument.file` handler.
+        """
+        return self._file(path, region)
+
+    @handler.register('file')
     def file(self, path: str, region: str = None) -> bytes:
         """
-        The final modifier `f:path` or `file:path` returns the contents of the file located
-        at the given path. The path may contain wildcard characters, but this pattern has to
-        match a single file. It is also possible to use the handler as `file[offset]` or as
-        `file[offset:count]` to read `count` many bytes from the file at the given offset.
+        Returns the contents of the file located at the given path. The path may contain
+        wildcard characters, but this pattern has to match a single file. It is also possible
+        to use the handler as `file[offset]` or as `file[offset:count]` to read `count`
+        many bytes from the file at the given offset.
         """
+        return self._file(path, region)
+
+    def _file(self, path: str, region: str) -> bytes:
         def read(data: Optional[Chunk] = None):
             if not region:
                 bounds = slice(0, None)
@@ -548,8 +562,6 @@ class DelayedArgument(LazyEvaluation):
             with path.open('rb') as stream:
                 stream.seek(bounds.start or 0)
                 return stream.read(bounds.stop)
-        if isbuffer(path):
-            path = path.decode('utf8')
         path: Path = one(Path.cwd().glob(path))
         try:
             return read()
@@ -614,7 +626,7 @@ class DelayedArgument(LazyEvaluation):
             return obj
         raise ArgumentTypeError(F'The meta variable {name} is of type {type(obj).__name__} and no conversion is known.')
 
-    @handler.register('var', '?', final=True)
+    @handler.register('var', '$', final=True)
     def var(self, name: str) -> bytes:
         """
         The final handler `var:name` contains the value of the meta variable `name`.
@@ -629,7 +641,7 @@ class DelayedArgument(LazyEvaluation):
             return self._interpret_variable(name, result)
         return extract
 
-    @handler.register('xvar', '!', final=True)
+    @handler.register('xvar', '#', final=True)
     def xvar(self, name: str) -> bytes:
         """
         The final handler `xvar:name` contains the value of the meta variable `name`.
@@ -645,18 +657,17 @@ class DelayedArgument(LazyEvaluation):
         return extract
 
     @handler.register('e', 'E', 'eval')
-    def eval(self, expression: Union[str, ByteString]) -> Any:
+    def eval(self, expression) -> Any:
         """
         Final modifier `e:expression` or `eval:expression`; uses a `refinery.lib.argformats.PythonExpression`
         parser to process expressions. The expression can contain any meta variable that is attached to the
         chunk. The `refinery.cm` unit can be used to attach information such as chunk size and the chunk
         index within the current frame (see `refinery.lib.frame`).
         """
+        if isbuffer(expression):
+            expression = expression.decode('utf8')
         if not isinstance(expression, str):
-            try:
-                expression = expression.decode('ascii')
-            except AttributeError:
-                return expression
+            return expression
         return LazyPythonExpression(expression)
 
     @handler.register('btoi')
@@ -710,29 +721,43 @@ class DelayedArgument(LazyEvaluation):
         return chunks.pack(integers, size, bigE)
 
     @handler.register('inc')
-    def inc(self, it: Iterable[int], wrap=None) -> Iterable[int]:
+    def inc(self, it: Iterable[int], precision=None) -> Iterable[int]:
+        F"""
+        The modifier `inc:it` or `inc[N={_DEFAULT_BITS}]:it` expects a sequence `it` of integers
+        (a binary string is interpreted as the sequence of its byte values), iterates it cyclically
+        and perpetually adds an increasing counter to the result. If the number `N` is nonzero,
+        then the counter is limited to `N` bits.
         """
-        The modifier `inc:it` or `inc[N]:it` expects a sequence `it` of integers (a binary string
-        is interpreted as the sequence of its byte values), iterates it cyclically and perpetually
-        adds an increasing counter to the result. If the number `N` is specified, then the counter
-        is reduced modulo `N`.
-        """
-        def delay(_):
-            k = itertools.cycle(range(number(wrap))) if wrap else itertools.count()
-            for item in infinitize(it):
-                yield item + next(k)
+        precision = precision and int(precision, 0) or _DEFAULT_BITS
+        it = infinitize(it)
+        if precision:
+            def delay(_):
+                mask = (1 << precision) - 1
+                for a, b in zip(it, itertools.cycle(range(mask + 1))):
+                    yield a + b & mask
+        else:
+            def delay(_):
+                for a, b in zip(it, itertools.count()):
+                    yield a + b
         return delay
 
     @handler.register('dec')
-    def dec(self, it: Iterable[int], wrap=None) -> Iterable[int]:
+    def dec(self, it: Iterable[int], precision=None) -> Iterable[int]:
         """
-        Identical to `refinery.lib.argformats.DelayedNumSeqArgument.inc`, but the counter is
-        subtracted from `it`.
+        Identical to `refinery.lib.argformats.DelayedNumSeqArgument.inc`, but decreasing the counter
+        rather than increasing it.
         """
-        def delay(_):
-            k = itertools.cycle(range(number(wrap))) if wrap else itertools.count()
-            for item in infinitize(it):
-                yield item - next(k)
+        precision = precision and int(precision, 0) or _DEFAULT_BITS
+        it = infinitize(it)
+        if precision:
+            def delay(_):
+                mask = (1 << precision) - 1
+                for a, b in zip(it, itertools.cycle(range(mask + 1))):
+                    yield a - b & mask
+        else:
+            def delay(_):
+                for a, b in zip(it, itertools.count()):
+                    yield a - b
         return delay
 
     @handler.register('take')
@@ -770,10 +795,10 @@ class DelayedArgument(LazyEvaluation):
         skip: Optional[str] = None,
         precision: Optional[str] = None
     ) -> Iterable[int]:
-        """
+        F"""
         The final handler
 
-            accu[seed=0,skip=1,precision=64]:update[#feed]
+            accu[seed=0,skip=1,precision={_DEFAULT_BITS}]:update[#feed]
 
         expects `seed`, `skip`, `update`, and `feed` to be Python expressions. It generates an infinite integer
         sequence maintaining an internal state `A`: The initial value for `A` is `seed`. Each subsequent state is
@@ -812,7 +837,7 @@ class DelayedArgument(LazyEvaluation):
         seed = seed and PythonExpression(seed, all_variables_allowed=True)
         feed = feed and PythonExpression(feed, all_variables_allowed=True)
         skip = 1 if skip is None else int(skip, 0)
-        precision = precision and int(precision, 0) or 64
+        precision = precision and int(precision, 0) or _DEFAULT_BITS
         mask = precision and (1 << precision) - 1
 
         def finalize(data: Optional[Chunk] = None):
@@ -892,6 +917,8 @@ class DelayedBinaryArgument(DelayedArgument):
     def __call__(self, data: Optional[ByteString] = None) -> bytes:
         value = super().__call__(data=data)
         if not isbuffer(value):
+            if isinstance(value, str):
+                return value.encode('utf8')
             raise ArgumentTypeError(
                 F'The expression {self.expression} returned a value of type {type(value).__name__}, '
                 R'which could not be converted to a byte string.'
