@@ -28,7 +28,7 @@ class secstr(Unit):
         self, key: arg(
             help='Secure string encryption 16-byte AES key; the default are the bytes from 1 to 16.'
         ) = bytes(range(1, 17)),
-        iv: arg('-I', help='Optionally specify an IV to use for encryption.') = None
+        iv: arg('-i', help='Optionally specify an IV to use for encryption.') = None
     ):
         super().__init__(key=key, iv=iv)
 
