@@ -1,19 +1,28 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-import py7zr
+from __future__ import annotations
+from typing import TYPE_CHECKING
 
-from ....lib.structures import MemoryFile
-from . import ArchiveUnit
+from refinery.lib.structures import MemoryFile
+from refinery.units.formats.archive import ArchiveUnit
+
+if TYPE_CHECKING:
+    from py7zr import SevenZipFile, FileInfo
 
 
 class xt7z(ArchiveUnit):
     """
     Extract files from a 7zip archive.
     """
+    @ArchiveUnit.Requires('py7zr', optional=False)
+    def _py7zr():
+        import py7zr
+        return py7zr
+
     def unpack(self, data):
 
         def mk7z(**keywords):
-            return py7zr.SevenZipFile(MemoryFile(mv[zp:]), **keywords)
+            return self._py7zr.SevenZipFile(MemoryFile(mv[zp:]), **keywords)
 
         pwd = self.args.pwd
         mv = memoryview(data)
@@ -26,7 +35,7 @@ class xt7z(ArchiveUnit):
             for pwd in self._COMMON_PASSWORDS:
                 try:
                     problem = archive.testzip()
-                except py7zr.PasswordRequired:
+                except self._py7zr.PasswordRequired:
                     problem = True
                 if not problem:
                     break
@@ -34,7 +43,7 @@ class xt7z(ArchiveUnit):
                 archive = mk7z(password=pwd)
 
         for info in archive.list():
-            def extract(archive: py7zr.SevenZipFile = archive, info: py7zr.FileInfo = info):
+            def extract(archive: SevenZipFile = archive, info: FileInfo = info):
                 archive.reset()
                 return archive.read(info.filename).get(info.filename).read()
             if info.is_directory:
