@@ -34,14 +34,18 @@ class hexload(HexViewer):
                     (?:\s{1,2}[a-f0-9]{2})*     # unless it was just a single byte
                 )?
             )
-            | (?:[a-f0-9]{4}\s{1,2}(?:[a-f0-9]{4}(?:\s{1,2}[a-f0-9]{4})*)?)   # 2-byte chunks
-            | (?:[a-f0-9]{8}\s{1,2}(?:[a-f0-9]{8}(?:\s{1,2}[a-f0-9]{8})*)?)   # 4-byte chunks
+            | (?:[a-f0-9]{4}\s{1,2}             # 2-byte chunks
+              (?:[a-f0-9]{4}
+              (?:\s{1,2}[a-f0-9]{4})*)?)
+            | (?:[a-f0-9]{8}\s{1,2}             # 4-byte chunks
+              (?:[a-f0-9]{8}
+              (?:\s{1,2}[a-f0-9]{8})*)?)
             | (?:(?:[a-f0-9]{2})+)              # continuous line of hexadecimal characters
         )(?=\s|$)                               # terminated by a whitespace or line end
         """
 
-    def __init__(self, hexaddr=True, width=0, expand=False):
-        super().__init__(hexaddr=hexaddr, width=width, expand=expand)
+    def __init__(self, blocks=1, dense=False, expand=False, narrow=True, width=0):
+        super().__init__(blocks=blocks, dense=dense, expand=expand, narrow=narrow, width=width)
         self._hexline_pattern = re.compile(F'{make_hexline_pattern(1)}(?:[\r\n]|$)', flags=re.MULTILINE)
 
     def process(self, data: bytearray):
