@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from . import RegexUnit
+from refinery.units.pattern import RegexUnit
 
 
 class resplit(RegexUnit):
